"""
Tic Tac Toe Game
~~~~~~~~~~~~~~~~

A basic package to facilitate
games of tic-tac-toe

:copyright: (c) 2021-present Robert Offord
:license: MIT, see LICENSE for more details.

"""
__title__ = "tictacpy"
__author__ = "Robert Offord"
__license__ = 'MIT'
__copyright__ = 'Copyright 2021-present Robert Offord'
__version__ = '1.0.0'

from .game import TTT
from .errors import *
from .board import Board